/*
 * Author: Andrew Villadsen
 *
 * Copyright (c) 2017 Trustwave Holdings, Inc.
 * All Rights Reserved.
 *
 * This software is the confidential and proprietary information
 * of Trustwave Holdings, Inc.  Use of this software is governed by
 * the terms and conditions of the license statement and limited
 * warranty furnished with the software.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD TRUSTWAVE HOLDINGS INC.,
 * ITS RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST
 * ANY CLAIMS OR LIABILITIES ARISING OUT OF OR RESULTING FROM THE USE,
 * MODIFICATION, OR DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM,
 * BASED ON, AND/OR DERIVED FROM THIS SOURCE CODE FILE.
 */

import 'dart:async';

import 'package:angular_test/angular_test.dart';
import 'package:pageloader/html.dart';
import 'package:pageloader/objects.dart';

import 'package:tw_angular_test_utils/src/resolve_po_from.dart';

/// Resolve a page object for an overlay created with angular_component's overlay service,
/// i.e. material-popup or modal.
///
/// [overlaySource] is the "placeholder" element for the overlay that is inside your component's content.
/// It will usually be a material-popup or a modal element.
/// Basically, it's whatever has the pane-id attribute.
///
/// [overlayPOType] should be a Type assignable to the type parameter [T].
/// The type parameter [T] is really just a convenience to inform your code about what return type to expect.
Future<T> resolveOverlayPageObject<T>(
    NgTestFixture fixture, PageLoaderElement overlaySource, Type overlayPOType) async {
  final String paneId = await overlaySource.attributes['pane-id'];
  final String containerName = paneId.split('-')[0];

  final String paneSelector = '.acx-overlay-container[container-name="$containerName"] > div[pane-id="$paneId"]';

  return resolvePageObjectFrom(paneSelector, overlayPOType, fixture);
}
