/*
 * Author: Andrew Villadsen
 *
 * Copyright (c) 2017 Trustwave Holdings, Inc.
 * All Rights Reserved.
 *
 * This software is the confidential and proprietary information
 * of Trustwave Holdings, Inc.  Use of this software is governed by
 * the terms and conditions of the license statement and limited
 * warranty furnished with the software.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD TRUSTWAVE HOLDINGS INC.,
 * ITS RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST
 * ANY CLAIMS OR LIABILITIES ARISING OUT OF OR RESULTING FROM THE USE,
 * MODIFICATION, OR DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM,
 * BASED ON, AND/OR DERIVED FROM THIS SOURCE CODE FILE.
 */

import 'dart:async';
import 'dart:html';

import 'package:angular_test/angular_test.dart';
import 'package:pageloader/html.dart';
import 'package:pageloader/objects.dart';

/// Resolve a page object from a CSS selector in the global (document) context.
///
/// [poType] should be a Type assignable to the type parameter [T].
/// The type parameter [T] is really just a convenience to inform your code about what return type to expect.
Future<T> resolvePageObjectFrom<T>(String selector, Type poType, NgTestFixture fixture) {
  final Element context = fixture.rootElement.ownerDocument.querySelector(selector);

  final PageLoader pageLoader = new HtmlPageLoader(context, executeSyncedFn: (fn) async {
    await fn();
    return fixture.update();
  });

  return pageLoader.getInstance(poType);
}
