/*
 * Author: Andrew Villadsen
 *
 * Copyright (c) 2017 Trustwave Holdings, Inc.
 * All Rights Reserved.
 *
 * This software is the confidential and proprietary information
 * of Trustwave Holdings, Inc.  Use of this software is governed by
 * the terms and conditions of the license statement and limited
 * warranty furnished with the software.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD TRUSTWAVE HOLDINGS INC.,
 * ITS RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST
 * ANY CLAIMS OR LIABILITIES ARISING OUT OF OR RESULTING FROM THE USE,
 * MODIFICATION, OR DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM,
 * BASED ON, AND/OR DERIVED FROM THIS SOURCE CODE FILE.
 */

import 'dart:async';
import 'dart:convert';

import 'package:barback/barback.dart';
import 'package:path/path.dart';

// This transformer is essentially meant to customize (and is heavily based on) the pub serve transformer from
// the test package.

/// A transformer that adds a custom test HTML files that contain the assets generally needed by the portal framework.
class PortalTestHtmlTransformer extends Transformer {
  final allowExtensions = '.dart';

  PortalTestHtmlTransformer.asPlugin();

  Future apply(Transform transform) async {
    final AssetId id = transform.primaryInput.id;
    final AssetId htmlId = id.changeExtension('.html');
    final AssetId htmlHeadId = id.changeExtension('.head.html');
    final AssetId htmlBodyId = id.changeExtension('.body.html');

    if (await transform.hasInput(htmlId)) {
      return;
    }

    String headHtml = '';
    if (await transform.hasInput(htmlHeadId)) {
      final Asset htmlHeadAsset = await transform.getInput(htmlHeadId);
      headHtml = await htmlHeadAsset.readAsString();
    }

    String bodyHtml = '';
    if (await transform.hasInput(htmlBodyId)) {
      final Asset htmlBodyAsset = await transform.getInput(htmlBodyId);
      bodyHtml = await htmlBodyAsset.readAsString();
    }

    transform.addOutput(new Asset.fromString(
        htmlId,
        '''
<!DOCTYPE html>
<html>
<head>
    <title>${HTML_ESCAPE.convert(id.path)} Test</title>
    <!-- External Assets -->
    <link rel="stylesheet" href="packages/tw_ui_common/font-awesome/font-tw.min.css">
    <link rel="stylesheet" href="packages/tw_ui_common/font-awesome/font-awesome-animation.min.css">
    <link rel="stylesheet" type="text/css" href="packages/tw_ui_common/material/icon.css">
    <link rel="stylesheet" href="packages/tw_ui_common/tw/tw_flex_layout.css">
    <link rel="stylesheet" href="packages/tw_ui_common/tw/tw_global.css">
    <link rel="stylesheet" href="packages/tw_ui_common/opentip/opentip.css">
    <script defer src="packages/tw_ui_common/opentip/opentip-native.js"></script>
    <script defer src="packages/tw_ui_common/squire/richtexteditor.js"></script>
    <script defer src="packages/tw_ui_common/squire/squire-raw.js"></script>
${headHtml}
    <!-- Test Scripts -->
    <link rel="x-dart-test"
          href="${HTML_ESCAPE.convert(url.basename(id.path))}">
    <script src="packages/test/dart.js"></script>
</head>
<body>${bodyHtml}</body>
</html>
      '''));
  }
}
