/*
 * Author: Andrew Villadsen
 *
 * Copyright (c) 2017 Trustwave Holdings, Inc.
 * All Rights Reserved.
 *
 * This software is the confidential and proprietary information
 * of Trustwave Holdings, Inc.  Use of this software is governed by
 * the terms and conditions of the license statement and limited
 * warranty furnished with the software.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD TRUSTWAVE HOLDINGS INC.,
 * ITS RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST
 * ANY CLAIMS OR LIABILITIES ARISING OUT OF OR RESULTING FROM THE USE,
 * MODIFICATION, OR DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM,
 * BASED ON, AND/OR DERIVED FROM THIS SOURCE CODE FILE.
 */

@Tags(const ['aot'])

import 'dart:async';

import 'package:angular2/angular2.dart';
import 'package:angular_test/angular_test.dart';
import 'package:pageloader/objects.dart';
import 'package:test/test.dart';

import 'package:tw_angular_test_utils/src/opentip.dart';

// We used a fixed example of an opentip container to test the opentip PO resolver (see opentip_test.html)
// The reason for this is that the opentip bindings are in ui_angular, which depends on this package.
// So we use an artificial test to avoid a circular dependency.
// The twa-tooltip tests fill the gap in terms of testing the opentip PO resolver.

@AngularEntrypoint()
void main() {
  NgTestBed<TestComponent> testBed = new NgTestBed<TestComponent>();
  NgTestFixture<TestComponent> fixture;
  OpenTipPO openTipPO;

  tearDown(disposeAnyRunningTest);

  test('resolves to the opentip container', () async {
    fixture = await testBed.create();

    openTipPO = await resolveOpenTipPageObject<OpenTipPO>(OpenTipPO, fixture);

    expect(await openTipPO.text, 'Medium');
  });
}

@Component(
  selector: 'test-component',
  template: '',
)
class TestComponent {}

class OpenTipPO {
  @ByClass('ot-content')
  PageLoaderElement _content;

  Future<String> get text => _content.visibleText;
}
