/*
 * Author: Andrew Villadsen
 *
 * Copyright (c) 2017 Trustwave Holdings, Inc.
 * All Rights Reserved.
 *
 * This software is the confidential and proprietary information
 * of Trustwave Holdings, Inc.  Use of this software is governed by
 * the terms and conditions of the license statement and limited
 * warranty furnished with the software.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD TRUSTWAVE HOLDINGS INC.,
 * ITS RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST
 * ANY CLAIMS OR LIABILITIES ARISING OUT OF OR RESULTING FROM THE USE,
 * MODIFICATION, OR DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM,
 * BASED ON, AND/OR DERIVED FROM THIS SOURCE CODE FILE.
 */

@Tags(const ['aot'])

import 'dart:async';

import 'package:angular2/angular2.dart';
import 'package:angular_components/angular_components.dart';
import 'package:angular_test/angular_test.dart';
import 'package:pageloader/objects.dart';
import 'package:test/test.dart';

import 'package:tw_angular_test_utils/src/overlay.dart';

@AngularEntrypoint()
void main() {
  NgTestBed<OverlayTestComponent> testBed = new NgTestBed<OverlayTestComponent>();
  NgTestFixture<OverlayTestComponent> fixture;
  OverlayTestPO overlayTestPO;

  tearDown(disposeAnyRunningTest);

  test('matches sources to overlay panes', () async {
    fixture = await testBed.create();
    overlayTestPO = await fixture.resolvePageObject(OverlayTestPO);

    Iterable<OverlayPanePO> overlayPanePOs = await overlayTestPO.resolveOverlayPOs(fixture);

    expect(await Future.wait(overlayPanePOs.map((pane) => pane.text)), ['Popup 1', 'Modal 2', 'Popup 3']);
  });
}

@Component(
    selector: 'overlay-test',
    directives: const [materialDirectives],
    providers: const [materialProviders],
    template: '''
  <div popupSource #source1="popupSource"></div>
  <material-popup [source]="source1" [visible]="true">Popup 1</material-popup>
  <modal [visible]="true">Modal 2</modal>
  <div popupSource #source2="popupSource"></div>
  <material-popup [source]="source2" [visible]="true">Popup 3</material-popup>
  ''')
class OverlayTestComponent {}

class OverlayPanePO {
  @root
  PageLoaderElement _pane;

  Future<String> get text => _pane.visibleText;
}

class OverlayTestPO {
  @ByCss('material-popup, modal')
  List<PageLoaderElement> _overlaySources;

  Future<Iterable<OverlayPanePO>> resolveOverlayPOs(NgTestFixture fixture) => Future.wait(_overlaySources
      .map((overlaySource) => resolveOverlayPageObject<OverlayPanePO>(fixture, overlaySource, OverlayPanePO)));
}
