/*
 * Author: Andrew Villadsen
 *
 * Copyright (c) 2017 Trustwave Holdings, Inc.
 * All Rights Reserved.
 *
 * This software is the confidential and proprietary information
 * of Trustwave Holdings, Inc.  Use of this software is governed by
 * the terms and conditions of the license statement and limited
 * warranty furnished with the software.
 *
 * IN PARTICULAR, YOU WILL INDEMNIFY AND HOLD TRUSTWAVE HOLDINGS INC.,
 * ITS RELATED COMPANIES AND ITS SUPPLIERS, HARMLESS FROM AND AGAINST
 * ANY CLAIMS OR LIABILITIES ARISING OUT OF OR RESULTING FROM THE USE,
 * MODIFICATION, OR DISTRIBUTION OF PROGRAMS OR FILES CREATED FROM,
 * BASED ON, AND/OR DERIVED FROM THIS SOURCE CODE FILE.
 */

@Tags(const ['transformer'])

import 'package:transformer_test/utils.dart';
import 'package:test/test.dart';

import 'package:tw_angular_test_utils/transformer.dart';

void main() {
  testPhases(
      'creates Portal test HTML file',
      [
        [new PortalTestHtmlTransformer.asPlugin()]
      ],
      {
        'foo|test/foo_test.dart': 'final String message = "This should be unaltered";',
      },
      {
        'foo|test/foo_test.dart': 'final String message = "This should be unaltered";',
        'foo|test/foo_test.html': '''
<!DOCTYPE html>
<html>
<head>
    <title>test&#47;foo_test.dart Test</title>
    <!-- External Assets -->
    <link rel="stylesheet" href="packages/tw_ui_common/font-awesome/font-tw.min.css">
    <link rel="stylesheet" href="packages/tw_ui_common/font-awesome/font-awesome-animation.min.css">
    <link rel="stylesheet" type="text/css" href="packages/tw_ui_common/material/icon.css">
    <link rel="stylesheet" href="packages/tw_ui_common/tw/tw_flex_layout.css">
    <link rel="stylesheet" href="packages/tw_ui_common/tw/tw_global.css">
    <link rel="stylesheet" href="packages/tw_ui_common/opentip/opentip.css">
    <script defer src="packages/tw_ui_common/opentip/opentip-native.js"></script>
    <script defer src="packages/tw_ui_common/squire/richtexteditor.js"></script>
    <script defer src="packages/tw_ui_common/squire/squire-raw.js"></script>

    <!-- Test Scripts -->
    <link rel="x-dart-test"
          href="foo_test.dart">
    <script src="packages/test/dart.js"></script>
</head>
<body></body>
</html>
    '''
      },
      formatter: StringFormatter.noSurroundingWhitespace);

  testPhases(
      'does not overwrite existing HTML file',
      [
        [new PortalTestHtmlTransformer.asPlugin()]
      ],
      {
        'foo|test/foo_test.dart': 'final String message = "This should be unaltered";',
        'foo|test/foo_test.html': '<body>This should also be unaltered</body>'
      },
      {
        'foo|test/foo_test.dart': 'final String message = "This should be unaltered";',
        'foo|test/foo_test.html': '<body>This should also be unaltered</body>'
      },
      formatter: StringFormatter.noSurroundingWhitespace);

  testPhases(
      'inserts the body partial HTML file',
      [
        [new PortalTestHtmlTransformer.asPlugin()]
      ],
      {
        'foo|test/foo_test.dart': 'final String message = "This should be unaltered";',
        'foo|test/foo_test.body.html': '<div>foo</div>'
      },
      {
        'foo|test/foo_test.dart': 'final String message = "This should be unaltered";',
        'foo|test/foo_test.body.html': '<div>foo</div>',
        'foo|test/foo_test.html': '''
<!DOCTYPE html>
<html>
<head>
    <title>test&#47;foo_test.dart Test</title>
    <!-- External Assets -->
    <link rel="stylesheet" href="packages/tw_ui_common/font-awesome/font-tw.min.css">
    <link rel="stylesheet" href="packages/tw_ui_common/font-awesome/font-awesome-animation.min.css">
    <link rel="stylesheet" type="text/css" href="packages/tw_ui_common/material/icon.css">
    <link rel="stylesheet" href="packages/tw_ui_common/tw/tw_flex_layout.css">
    <link rel="stylesheet" href="packages/tw_ui_common/tw/tw_global.css">
    <link rel="stylesheet" href="packages/tw_ui_common/opentip/opentip.css">
    <script defer src="packages/tw_ui_common/opentip/opentip-native.js"></script>
    <script defer src="packages/tw_ui_common/squire/richtexteditor.js"></script>
    <script defer src="packages/tw_ui_common/squire/squire-raw.js"></script>

    <!-- Test Scripts -->
    <link rel="x-dart-test"
          href="foo_test.dart">
    <script src="packages/test/dart.js"></script>
</head>
<body><div>foo</div></body>
</html>
    '''
      },
      formatter: StringFormatter.noSurroundingWhitespace);

  testPhases(
      'inserts the head HTML file',
      [
        [new PortalTestHtmlTransformer.asPlugin()]
      ],
      {
        'foo|test/foo_test.dart': 'final String message = "This should be unaltered";',
        'foo|test/foo_test.head.html': '''
<script defer src="packages/foo/script.js"></script>
<link rel="stylesheet" href="packages/foo/styles.css">
'''
            .trim()
      },
      {
        'foo|test/foo_test.dart': 'final String message = "This should be unaltered";',
        'foo|test/foo_test.head.html': '''
<script defer src="packages/foo/script.js"></script>
<link rel="stylesheet" href="packages/foo/styles.css">
'''
            .trim(),
        'foo|test/foo_test.html': '''
<!DOCTYPE html>
<html>
<head>
    <title>test&#47;foo_test.dart Test</title>
    <!-- External Assets -->
    <link rel="stylesheet" href="packages/tw_ui_common/font-awesome/font-tw.min.css">
    <link rel="stylesheet" href="packages/tw_ui_common/font-awesome/font-awesome-animation.min.css">
    <link rel="stylesheet" type="text/css" href="packages/tw_ui_common/material/icon.css">
    <link rel="stylesheet" href="packages/tw_ui_common/tw/tw_flex_layout.css">
    <link rel="stylesheet" href="packages/tw_ui_common/tw/tw_global.css">
    <link rel="stylesheet" href="packages/tw_ui_common/opentip/opentip.css">
    <script defer src="packages/tw_ui_common/opentip/opentip-native.js"></script>
    <script defer src="packages/tw_ui_common/squire/richtexteditor.js"></script>
    <script defer src="packages/tw_ui_common/squire/squire-raw.js"></script>
<script defer src="packages/foo/script.js"></script>
<link rel="stylesheet" href="packages/foo/styles.css">
    <!-- Test Scripts -->
    <link rel="x-dart-test"
          href="foo_test.dart">
    <script src="packages/test/dart.js"></script>
</head>
<body></body>
</html>
    '''
      },
      formatter: StringFormatter.noSurroundingWhitespace);
}
